@@ -15,10 +15,20 @@ class Authorizable:
         """
         raise NotImplementedError
 
-    def get_principal_authorizations(self, principal):
+    def get_subject_authorizations(self, subject):
         """Return a set holding the authorizations that
-        the principal has on this entity. The default
+        the subject has on this entity. The default
         implementation returns an empty set, meaning
         no permissions.
         """
-        return set()
+        realm = self.get_realm()
+        return (
+            self.get_resource_qualname(),
+            realm.get_realm_authorizations(subject, self)
+        )
+
+    def get_realm(self):
+        """Returns the authorization realm to which this
+        resource belongs.
+        """
+        raise NotImplementedError
