@@ -33,11 +33,8 @@ class AuthorizedModelBackend(ModelBackend):
         if obj is None:
             return None, set()
 
-        if isinstance(obj, Authorizable):
-            return (
-                obj.get_resource_qualname(),
-                obj.get_principal_authorizations(principal)
-            )
+        if issubclass(type(obj), Authorizable):
+            return obj.get_subject_authorizations(principal)
 
         resource_class = f"{obj._meta.app_label}.{obj._meta.object_name}".lower()
         resource_id = self.get_resource_id(obj)
